HookedModule

Struct HookedModule 

pub struct HookedModule<M, T: Float> { /* private fields */ }
A wrapper that adds hook storage around any Module.

HookedModule implements Module<T> itself, so it can be used anywhere the inner module could be used. Hooks are stored behind Mutexes and the wrapper is Send + Sync as long as the inner module is.

Implementations

Source

impl<M, T: Float> HookedModule<M, T>

pub fn new(module: M) -> Self

Wrap a module, enabling hook registration.

pub fn register_forward_hook(&self, hook: ForwardHook<T>) -> HookHandle

Register a hook that fires after forward.

The hook receives (&input, &output). Returns a HookHandle that can be used to unregister the hook.

pub fn register_forward_pre_hook(&self, hook: ForwardPreHook<T>) -> HookHandle

Register a hook that fires before forward.

The hook receives (&input) and returns a (possibly modified) input tensor. Returns a HookHandle.

pub fn register_backward_hook(&self, hook: BackwardHook<T>) -> HookHandle

Register a hook that fires during the backward pass.

The hook receives (&grad_input, &grad_output). Returns a HookHandle.

pub fn inner(&self) -> &M

Borrow the inner module.

pub fn inner_mut(&mut self) -> &mut M

Mutably borrow the inner module.

pub fn into_inner(self) -> M

Consume the wrapper and return the inner module.