pub struct HookedModule<M, T: Float> { /* private fields */ }Expand description
A wrapper that adds hook storage around any Module.
HookedModule implements Module<T> itself, so it can be used anywhere
the inner module could be used. Hooks are stored behind Mutexes and
the wrapper is Send + Sync as long as the inner module is.
Implementations
Sourceimpl<M, T: Float> HookedModule<M, T>
impl<M, T: Float> HookedModule<M, T>
Sourcepub fn register_forward_hook(&self, hook: ForwardHook<T>) -> HookHandle
pub fn register_forward_hook(&self, hook: ForwardHook<T>) -> HookHandle
Register a hook that fires after forward.
The hook receives (&input, &output). Returns a HookHandle that
can be used to unregister the hook.
Sourcepub fn register_forward_pre_hook(&self, hook: ForwardPreHook<T>) -> HookHandle
pub fn register_forward_pre_hook(&self, hook: ForwardPreHook<T>) -> HookHandle
Register a hook that fires before forward.
The hook receives (&input) and returns a (possibly modified) input
tensor. Returns a HookHandle.
Sourcepub fn register_backward_hook(&self, hook: BackwardHook<T>) -> HookHandle
pub fn register_backward_hook(&self, hook: BackwardHook<T>) -> HookHandle
Register a hook that fires during the backward pass.
The hook receives (&grad_input, &grad_output). Returns a
HookHandle.
Sourcepub fn into_inner(self) -> M
pub fn into_inner(self) -> M
Consume the wrapper and return the inner module.